@@ -11,10 +11,10 @@ from cli_helpers.tabular_output import preprocessors
 import click
 
 from prompt_toolkit.shortcuts import PromptSession
-from .packages import special
 from .sqlexecute import SQLExecute
 from .sqlinternal import Create_file
 from .sqlcliexception import SQLCliException
+from .commandanalyze import register_special_command
 from .__init__ import __version__
 from .sqlparse import SQLAnalyze
 
@@ -43,19 +43,22 @@ class SQLCli(object):
     sqlscript = None
     sqlexecute = None
     nologo = None
+    logon = None
+    logfile = None
 
     def __init__(
             self,
-            logfile=None,
-            auto_vertical_output=False,
+            logon=None,
+            logfilename=None,
             sqlscript=None,
             nologo=None
     ):
         self.sqlexecute = SQLExecute()
-        __sqlinternal__sqlexecute__ = self.sqlexecute
-        self.logfile = logfile
+        if logfilename is not None:
+            self.logfile = open(logfilename, mode="a", encoding="utf-8")
         self.sqlscript = sqlscript
         self.nologo = nologo
+        self.logon = logon
 
         self.formatter = TabularOutputFormatter(format_name='ascii')
         self.formatter.sqlcli = self
@@ -73,7 +76,7 @@ class SQLCli(object):
     def register_special_commands(self):
 
         # 加载数据库驱动
-        special.register_special_command(
+        register_special_command(
             self.load_driver,
             ".load",
             ".load",
@@ -82,7 +85,7 @@ class SQLCli(object):
         )
 
         # 连接数据库
-        special.register_special_command(
+        register_special_command(
             self.connect_db,
             ".connect",
             ".connect",
@@ -90,17 +93,8 @@ class SQLCli(object):
             aliases=("connect", "\\c"),
         )
 
-        special.register_special_command(
-            self.change_table_format,
-            ".mode",
-            "\\T",
-            "Change the table format used to output results.",
-            aliases=("tableformat", "\\T"),
-            case_sensitive=True,
-        )
-
         # 从文件中执行脚本
-        special.register_special_command(
+        register_special_command(
             self.execute_from_file,
             "start",
             "\\. filename",
@@ -109,7 +103,7 @@ class SQLCli(object):
         )
 
         # 设置各种参数选项
-        special.register_special_command(
+        register_special_command(
             self.set_options,
             "set",
             "set parameter parameter_value",
@@ -118,7 +112,7 @@ class SQLCli(object):
         )
 
         # 执行特殊的命令
-        special.register_special_command(
+        register_special_command(
             self.execute_internal_command,
             "__internal__",
             "execute internal command.",
@@ -126,29 +120,19 @@ class SQLCli(object):
             aliases=("__internal__",),
         )
 
-    def change_table_format(self, arg, **_):
-        try:
-            self.formatter.format_name = arg
-            yield None, None, None, "Changed table format to {}".format(arg)
-        except ValueError:
-            msg = "Table format {} not recognized. Allowed formats:".format(arg)
-            for table_type in self.formatter.supported_formats:
-                msg += "\n\t{}".format(table_type)
-            yield None, None, None, msg
-
     # 加载JDBC驱动文件
     def load_driver(self, arg, **_):
         if arg is None:
-            raise Exception("Missing required argument, load [driver file name] [driver class name].")
+            raise SQLCliException("Missing required argument, load [driver file name] [driver class name].")
         elif arg == "":
-            raise Exception("Missing required argument, load [driver file name] [driver class name].")
+            raise SQLCliException("Missing required argument, load [driver file name] [driver class name].")
         else:
             load_parameters = str(arg).split();
             if len(load_parameters) != 2:
                 self.logger.debug('arg = ' + str(load_parameters))
-                raise Exception("Missing required argument, load [driver file name] [driver class name].")
+                raise SQLCliException("Missing required argument, load [driver file name] [driver class name].")
             if not os.path.exists(str(load_parameters[0])):
-                raise Exception("driver file [" + str(arg) + "] does not exist.")
+                raise SQLCliException("driver file [" + str(arg) + "] does not exist.")
 
             # 如果jar包或者驱动类发生了变化，则当前数据库连接自动失效
             if self.jar_file:
@@ -172,13 +156,13 @@ class SQLCli(object):
     # 连接数据库
     def connect_db(self, arg, **_):
         if arg is None:
-            raise Exception("Missing required argument\n." + "connect [user name]/[password]@" +
+            raise SQLCliException("Missing required argument\n." + "connect [user name]/[password]@" +
                             "jdbc:[db type]:[driver type]://[host]:[port]/[service name]")
         elif arg == "":
-            raise Exception("Missing required argument\n." + "connect [user name]/[password]@" +
+            raise SQLCliException("Missing required argument\n." + "connect [user name]/[password]@" +
                             "jdbc:[db type]:[driver type]://[host]:[port]/[service name]")
         elif self.jar_file is None:
-            raise Exception("Please load driver first.")
+            raise SQLCliException("Please load driver first.")
 
         # 去掉为空的元素
         connect_parameters = [var for var in re.split(r'//|:|@|/', arg) if var]
@@ -264,7 +248,7 @@ class SQLCli(object):
             yield (
                 "Current set options: ",
                 m_Result,
-                ["option","value"],
+                ["option", "value"],
                 ""
             )
         else:
@@ -311,6 +295,7 @@ class SQLCli(object):
         # 不认识的internal命令
         raise SQLCliException("Unknown internal Command. Please double check.")
 
+    # 主程序
     def run_cli(self):
         iterations = 0
 
@@ -346,8 +331,6 @@ class SQLCli(object):
                         break
                 text = full_text
 
-                special.iocommands.set_expanded_output(False)
-
             # 如果文本是空行，直接跳过
             if not text.strip():
                 return
@@ -412,10 +395,16 @@ class SQLCli(object):
                                   "SQLCLI_CONNECTION_CLASS_NAME"])
                 iterations += 1
 
-            # 如果传递的参数中有SQL文件，先执行SQL文件
+            # 如果用户制定了用户名，口令，尝试直接进行数据库连接
+            if self.logon:
+                one_iteration("connect " + str(self.logon))
+
+            # 如果传递的参数中有SQL文件，先执行SQL文件, 执行完成后自动退出
             if self.sqlscript:
                 one_iteration('start ' + self.sqlscript)
                 iterations += 1
+                one_iteration('exit')
+                iterations += 1
 
             # 循环从控制台读取命令
             while True:
@@ -543,17 +532,22 @@ class SQLCli(object):
 
 
 @click.command()
-@click.option("-V", "--version", is_flag=True, help="Output sqlcli's version.")
+@click.option("--version", is_flag=True, help="Output sqlcli's version.")
+@click.option(
+    "--logon",
+    type=str,
+    help="logon user name and password. user/pass",
+)
 @click.option(
-    "-l",
     "--logfile",
-    type=click.File(mode="a", encoding="utf-8"),
+    type=str,
     help="Log every query and its results to a file.",
 )
-@click.option("-e", "--execute", type=str, help="Execute SQL script.")
+@click.option("--execute", type=str, help="Execute SQL script.")
 @click.option("--nologo", is_flag=True, help="Execute with silent mode.")
 def cli(
         version,
+        logon,
         logfile,
         execute,
         nologo
@@ -563,28 +557,14 @@ def cli(
         sys.exit(0)
 
     sqlcli = SQLCli(
-        logfile=logfile,
+        logfilename=logfile,
+        logon=logon,
         sqlscript=execute,
         nologo=nologo
     )
 
-    if sys.stdin.isatty():
-        sqlcli.run_cli()
-    else:
-        stdin = click.get_text_stream("stdin")
-        stdin_text = stdin.read()
-
-        try:
-            sys.stdin = open("/dev/tty")
-        except (FileNotFoundError, OSError):
-            sqlcli.logger.warning("Unable to open TTY as stdin.")
-
-        try:
-            sqlcli.run_query(stdin_text, True)
-            exit(0)
-        except Exception as e:
-            click.secho(str(e), err=True, fg="red")
-            exit(1)
+    # 运行主程序
+    sqlcli.run_cli()
 
 
 def is_select(status):
